@@ -4,6 +4,9 @@ import subprocess
 
 class Error (Exception): pass
 
+allowed_assemblers = ['canu', 'spades'] 
+allowed_data_types = ['pacbio-raw', 'pacbio-corrected', 'nanopore-raw', 'nanopore-corrected']
+
 def syscall(cmd, allow_fail=False, verbose=False):
     if verbose:
         print('syscall:', cmd, flush=True)
