@@ -10,7 +10,7 @@ def run():
     parser.add_argument('--min_length', type=int, help='Minimum length in amino acids [%(default)s]', default=333, metavar='INT')
     parser.add_argument('--max_length', type=int, help='Maximum length in amino acids [%(default)s]', default=500, metavar='INT')
     parser.add_argument('--uniprot_search', help='Uniprot search term [%(default)s]', default='dnaa', metavar='STRING')
-    parser.add_argument('--name_re', help='Each sequence name must match this regular expression [%(default)s]', default='"Chromosomal replication initiat(or|ion) protein.*dnaa"', metavar='STRING')
+    parser.add_argument('--name_re', help='Each sequence name must match this regular expression [%(default)s]', default='Chromosomal replication initiat(or|ion) protein.*dnaa', metavar='STRING')
     parser.add_argument('--name_re_case_sensitive', action='store_true', help='Do a case-sensitive match to regular expression given by --name_re. Default is to ignore case.')
 
     parser.add_argument('outprefix', help='Prefix of output files', metavar='output prefix')
